@@ -34,6 +34,7 @@
 int UsrInputType[3]={SI_GAMEPAD,SI_GAMEPAD,SIFC_NONE};
 int InputType[3];
 static int cspec;
+static int doubled = 1;
    
 int gametype;
 
@@ -218,6 +219,7 @@ static void KeyboardCommands(void)
 	FCEU_pause(1);
 #ifdef HAVE_LIBXSP
 	set_doubling(0);
+	doubled = 0;
 #endif
   }
 #endif
@@ -337,7 +339,10 @@ static void UpdateGamepad(void)
 	 FCEU_pause(0);
 #endif
 #ifdef HAVE_LIBXSP
-	 set_doubling(1);
+	 if(!doubled) {
+		 set_doubling(1);
+		 doubled = 1;
+	 }//reenable pixel doubling
 #endif
  	//printf("MouseData: %d %d %d\n",MouseData[0],MouseData[1],MouseData[2]);
 	 if(MouseData[0] >= BUTTON_LOCATIONS[BUTTON_B][0]){
